summaryrefslogtreecommitdiffstats
path: root/gst/rtpmanager/gstrtpclient.c
diff options
context:
space:
mode:
authorWim Taymans <wim.taymans@gmail.com>2007-05-28 16:37:47 +0000
committerWim Taymans <wim.taymans@gmail.com>2007-05-28 16:37:47 +0000
commit3a496fd7ebb90d12bad86c6ded97a75e134794f6 (patch)
treeb1f79cdcfe642548d51dd274fe7eb80ca1fe148f /gst/rtpmanager/gstrtpclient.c
parent6587432049097bc964946a21dd390b6c808476f2 (diff)
downloadgst-plugins-bad-3a496fd7ebb90d12bad86c6ded97a75e134794f6.tar.gz
gst-plugins-bad-3a496fd7ebb90d12bad86c6ded97a75e134794f6.tar.bz2
gst-plugins-bad-3a496fd7ebb90d12bad86c6ded97a75e134794f6.zip
Rename elements to avoid conflict with farsight elements with the same name. Fixes #430664.
Original commit message from CVS: * docs/plugins/gst-plugins-bad-plugins-docs.sgml: * docs/plugins/gst-plugins-bad-plugins-sections.txt: * gst/rtpmanager/gstrtpbin.c: (create_session), (create_stream), (gst_rtp_bin_class_init), (create_recv_rtp), (create_recv_rtcp), (create_send_rtp), (create_rtcp), (gst_rtp_bin_request_new_pad): * gst/rtpmanager/gstrtpclient.c: (create_stream), (gst_rtp_client_request_new_pad): * gst/rtpmanager/gstrtpjitterbuffer.c: (gst_rtp_jitter_buffer_clear_pt_map), (gst_rtp_jitter_buffer_loop): * gst/rtpmanager/gstrtpmanager.c: (plugin_init): * gst/rtpmanager/gstrtpptdemux.c: * gst/rtpmanager/gstrtpsession.c: (gst_rtp_session_class_init), (gst_rtp_session_request_new_pad): * gst/rtpmanager/gstrtpssrcdemux.c: Rename elements to avoid conflict with farsight elements with the same name. Fixes #430664.
Diffstat (limited to 'gst/rtpmanager/gstrtpclient.c')
-rw-r--r--gst/rtpmanager/gstrtpclient.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/gst/rtpmanager/gstrtpclient.c b/gst/rtpmanager/gstrtpclient.c
index 86c5f3cc..ba18f953 100644
--- a/gst/rtpmanager/gstrtpclient.c
+++ b/gst/rtpmanager/gstrtpclient.c
@@ -18,9 +18,9 @@
*/
/**
- * SECTION:element-rtpclient
+ * SECTION:element-gstrtpclient
* @short_description: handle media from one RTP client
* @see_also: rtpjitterbuffer, rtpbin, rtpsession
*
* <refsect2>
* <para>
@@ -38,7 +38,7 @@
* </para>
* </refsect2>
*
- * Last reviewed on 2007-04-02 (0.10.6)
+ * Last reviewed on 2007-04-02 (0.10.5)
*/
#ifdef HAVE_CONFIG_H
@@ -136,11 +136,11 @@ create_stream (GstRTPClient * rtpclient, guint32 ssrc)
stream->ssrc = ssrc;
stream->client = rtpclient;
- stream->jitterbuffer = gst_element_factory_make ("rtpjitterbuffer", NULL);
+ stream->jitterbuffer = gst_element_factory_make ("gstrtpjitterbuffer", NULL);
if (!stream->jitterbuffer)
goto no_jitterbuffer;
- stream->ptdemux = gst_element_factory_make ("rtpptdemux", NULL);
+ stream->ptdemux = gst_element_factory_make ("gstrtpptdemux", NULL);
if (!stream->ptdemux)
goto no_ptdemux;
@@ -180,14 +180,14 @@ create_stream (GstRTPClient * rtpclient, guint32 ssrc)
no_jitterbuffer:
{
g_free (stream);
- g_warning ("could not create rtpjitterbuffer element");
+ g_warning ("gstrtpclient: could not create gstrtpjitterbuffer element");
return NULL;
}
no_ptdemux:
{
gst_object_unref (stream->jitterbuffer);
g_free (stream);
- g_warning ("could not create rtpptdemux element");
+ g_warning ("gstrtpclient: could not create gstrtpptdemux element");
return NULL;
}
could_not_link:
@@ -195,7 +195,7 @@ could_not_link:
gst_bin_remove (GST_BIN_CAST (rtpclient), stream->jitterbuffer);
gst_bin_remove (GST_BIN_CAST (rtpclient), stream->ptdemux);
g_free (stream);
- g_warning ("could not link jitterbuffer and rtpptdemux element");
+ g_warning ("gstrtpclient: could not link jitterbuffer and ptdemux element");
return NULL;
}
}
@@ -455,27 +455,27 @@ gst_rtp_client_request_new_pad (GstElement * element,
/* ERRORS */
wrong_direction:
{
- g_warning ("rtpclient: request pad that is not a SINK pad");
+ g_warning ("gstrtpclient: request pad that is not a SINK pad");
return NULL;
}
wrong_template:
{
- g_warning ("rtpclient: this is not our template");
+ g_warning ("gstrtpclient: this is not our template");
return NULL;
}
no_name:
{
- g_warning ("rtpclient: no padname was specified");
+ g_warning ("gstrtpclient: no padname was specified");
return NULL;
}
stream_exists:
{
- g_warning ("rtpclient: stream with SSRC %d already registered", ssrc);
+ g_warning ("gstrtpclient: stream with SSRC %d already registered", ssrc);
return NULL;
}
stream_not_found:
{
- g_warning ("rtpclient: stream with SSRC %d not yet registered", ssrc);
+ g_warning ("gstrtpclient: stream with SSRC %d not yet registered", ssrc);
return NULL;
}
}
@@ -18,9 +18,9 @@
* @short_description: handle media from one RTP client
- * @see_also: rtpjitterbuffer, rtpbin, rtpsession
+ * @see_also: gstrtpjitterbuffer, gstrtpbin, gstrtpsession
*
* <refsect2>